==> huaweicloudsdkhilens-3.1.96-py2.py3-none-any.whl: huaweicloudsdkhilens/v3/model/show_resource_tags_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowResourceTagsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'count': 'int',
        'tags': 'list[TagObject]'
    }

    attribute_map = {
        'count': 'count',
        'tags': 'tags'
    }

    def __init__(self, count=None, tags=None):
        """ShowResourceTagsResponse

        The model defined in huaweicloud sdk

        :param count: 满足条件的总数
        :type count: int
        :param tags: 资源标签对列表
        :type tags: list[:class:`huaweicloudsdkhilens.v3.TagObject`]
        """
        
        super(ShowResourceTagsResponse, self).__init__()

        self._count = None
        self._tags = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if tags is not None:
            self.tags = tags

    @property
    def count(self):
        """Gets the count of this ShowResourceTagsResponse.

        满足条件的总数

        :return: The count of this ShowResourceTagsResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this ShowResourceTagsResponse.

        满足条件的总数

        :param count: The count of this ShowResourceTagsResponse.
        :type count: int
        """
        self._count = count

    @property
    def tags(self):
        """Gets the tags of this ShowResourceTagsResponse.

        资源标签对列表

        :return: The tags of this ShowResourceTagsResponse.
        :rtype: list[:class:`huaweicloudsdkhilens.v3.TagObject`]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ShowResourceTagsResponse.

        资源标签对列表

        :param tags: The tags of this ShowResourceTagsResponse.
        :type tags: list[:class:`huaweicloudsdkhilens.v3.TagObject`]
        """
        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowResourceTagsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkhilens-3.1.150-py2.py3-none-any.whl: huaweicloudsdkhilens/v3/model/show_resource_tags_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowResourceTagsResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'count': 'int',
        'tags': 'list[TagObject]'
    }

    attribute_map = {
        'count': 'count',
        'tags': 'tags'
    }

    def __init__(self, count=None, tags=None):
        r"""ShowResourceTagsResponse

        The model defined in huaweicloud sdk

        :param count: 满足条件的总数
        :type count: int
        :param tags: 资源标签对列表
        :type tags: list[:class:`huaweicloudsdkhilens.v3.TagObject`]
        """
        
        super(ShowResourceTagsResponse, self).__init__()

        self._count = None
        self._tags = None
        self.discriminator = None

        if count is not None:
            self.count = count
        if tags is not None:
            self.tags = tags

    @property
    def count(self):
        r"""Gets the count of this ShowResourceTagsResponse.

        满足条件的总数

        :return: The count of this ShowResourceTagsResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        r"""Sets the count of this ShowResourceTagsResponse.

        满足条件的总数

        :param count: The count of this ShowResourceTagsResponse.
        :type count: int
        """
        self._count = count

    @property
    def tags(self):
        r"""Gets the tags of this ShowResourceTagsResponse.

        资源标签对列表

        :return: The tags of this ShowResourceTagsResponse.
        :rtype: list[:class:`huaweicloudsdkhilens.v3.TagObject`]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        r"""Sets the tags of this ShowResourceTagsResponse.

        资源标签对列表

        :param tags: The tags of this ShowResourceTagsResponse.
        :type tags: list[:class:`huaweicloudsdkhilens.v3.TagObject`]
        """
        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowResourceTagsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
